@@ -6,10 +6,12 @@ use crate::macos::mach_ffi::{
 };
 use crate::traits::ReadoutError::MetricNotAvailable;
 use crate::traits::*;
+use byte_unit::AdjustedByte;
 use core_foundation::base::{TCFType, ToVoid};
 use core_foundation::dictionary::{CFMutableDictionary, CFMutableDictionaryRef};
 use core_foundation::number::{CFNumber, CFNumberRef};
 use core_foundation::string::CFString;
+use core_graphics::display::CGDisplay;
 use mach::kern_return::KERN_SUCCESS;
 use std::ffi::CString;
 use sysctl::{Ctl, Sysctl};
@@ -200,6 +202,48 @@ impl GeneralReadout for MacOSGeneralReadout {
         }
     }
 
+    fn resolution(&self) -> Result<String, ReadoutError> {
+        let displays = CGDisplay::active_displays();
+        if let Err(e) = displays {
+            return Err(ReadoutError::Other(format!(
+                "Error while querying active displays: {}",
+                e
+            )));
+        }
+
+        let displays: Vec<CGDisplay> = displays
+            .unwrap()
+            .iter()
+            .map(|id| CGDisplay::new(*id))
+            .filter(|d| d.is_active())
+            .collect();
+
+        let mut output: Vec<String> = Vec::with_capacity(displays.len());
+
+        for display in displays {
+            let (ui_width, ui_height) = (display.pixels_wide(), display.pixels_high());
+            let mut out_string: String = format!("{}x{}", ui_width, ui_height);
+
+            if let Some(mode) = display.display_mode() {
+                let (real_width, real_height) = (mode.pixel_width(), mode.pixel_height());
+                if real_width != ui_width || real_height != ui_height {
+                    out_string = format!(
+                        "{}x{}@{}fps (as {}x{})",
+                        real_width,
+                        real_height,
+                        mode.refresh_rate().round(),
+                        ui_width,
+                        ui_height
+                    );
+                }
+            }
+
+            output.push(out_string);
+        }
+
+        Ok(output.join("\n"))
+    }
+
     fn username(&self) -> Result<String, ReadoutError> {
         crate::shared::username()
     }
@@ -271,16 +315,16 @@ impl GeneralReadout for MacOSGeneralReadout {
             .value_string()?)
     }
 
-    fn cpu_cores(&self) -> Result<usize, ReadoutError> {
-        crate::shared::cpu_cores()
+    fn cpu_usage(&self) -> Result<usize, ReadoutError> {
+        crate::shared::cpu_usage()
     }
 
     fn cpu_physical_cores(&self) -> Result<usize, ReadoutError> {
         crate::shared::cpu_physical_cores()
     }
 
-    fn cpu_usage(&self) -> Result<usize, ReadoutError> {
-        crate::shared::cpu_usage()
+    fn cpu_cores(&self) -> Result<usize, ReadoutError> {
+        crate::shared::cpu_cores()
     }
 
     fn uptime(&self) -> Result<usize, ReadoutError> {
@@ -326,6 +370,10 @@ impl GeneralReadout for MacOSGeneralReadout {
 
         Ok(format!("{} {} {}", name, version, major_version_name))
     }
+
+    fn disk_space(&self) -> Result<(AdjustedByte, AdjustedByte), ReadoutError> {
+        crate::shared::disk_space(String::from("/"))
+    }
 }
 
 impl MemoryReadout for MacOSMemoryReadout {
@@ -484,7 +532,7 @@ impl PackageReadout for MacOSPackageReadout {
 
     fn count_pkgs(&self) -> Vec<(PackageManager, usize)> {
         let mut packages = Vec::new();
-        if extra::which("homebrew") {
+        if extra::which("brew") {
             match MacOSPackageReadout::count_homebrew() {
                 Some(c) => packages.push((PackageManager::Homebrew, c)),
                 _ => (),
