@@ -11,6 +11,8 @@ use std::process::{Command, Stdio};
 use std::{env, fs};
 use std::{ffi::CStr, path::PathBuf};
 
+use byte_unit::AdjustedByte;
+use std::ffi::CString;
 #[cfg(any(target_os = "linux", target_os = "macos", target_os = "android"))]
 use sysctl::SysctlError;
 
@@ -230,6 +232,30 @@ pub(crate) fn cpu_physical_cores() -> Result<usize, ReadoutError> {
     Ok(num_cpus::get_physical())
 }
 
+#[cfg(target_family = "unix")]
+pub(crate) fn disk_space(path: String) -> Result<(AdjustedByte, AdjustedByte), ReadoutError> {
+    let mut s: std::mem::MaybeUninit<libc::statfs> = std::mem::MaybeUninit::uninit();
+    let path = CString::new(path).expect("Could not create C string for disk usage path.");
+
+    if unsafe { libc::statfs(path.as_ptr(), s.as_mut_ptr()) } == 0 {
+        let stats: libc::statfs = unsafe { s.assume_init() };
+
+        let disk_size = stats.f_blocks * stats.f_bsize as u64;
+        let free = stats.f_bavail * stats.f_bsize as u64;
+
+        let used_byte =
+            byte_unit::Byte::from_bytes((disk_size - free) as u128).get_appropriate_unit(true);
+        let disk_size_byte =
+            byte_unit::Byte::from_bytes(disk_size as u128).get_adjusted_unit(used_byte.get_unit());
+
+        return Ok((used_byte, disk_size_byte));
+    }
+
+    Err(ReadoutError::Other(String::from(
+        "Error while trying to get statfs structure.",
+    )))
+}
+
 /// Obtain the value of a specified field from `/proc/meminfo` needed to calculate memory usage
 #[cfg(any(target_os = "linux", target_os = "netbsd", target_os = "android"))]
 pub(crate) fn get_meminfo_value(value: &str) -> u64 {
